@@ -1,4 +1,5 @@
 import os
+import sys
 
 def runAllTests():
     #in Python, the listdir command  returns files and directories (like typeing in "dir").
@@ -15,8 +16,9 @@ def runAllTests():
         print("Changing directory to "+directory)
         os.chdir(directory)
         try:
-            os.system("del __pycache__ /Q")
+            os.system("del __pycache__ /Q") #for windows
+            os.system("rm -r __pycache__ /Q") #for linux
         except:
             pass
-        os.system("pytest")
+        os.system(sys.executable +" -m pytest") #this is like typing "python -m pytest" but uses whichever version of python should be used, important for virtual environments and different systems https://stackoverflow.com/questions/8338854/how-to-run-py-test-against-different-versions-of-python
         os.chdir("..")
\ No newline at end of file
